@@ -1,13 +1,12 @@
 package XML::NewsML_G2::Media_Topic;
 
-# $Id: Media_Topic.pm 46519 2013-05-31 15:38:08Z apatecgortan $
+# $Id: Media_Topic.pm 55790 2014-08-26 18:30:30Z apatecgortan $
 
 use Moose;
 use namespace::autoclean;
 
+with 'XML::NewsML_G2::Role::HasQCode';
 
-has 'name', isa => 'Str', is => 'ro', required => 1;
-has 'qcode', isa => 'Str', is => 'ro', required => 1;
 has 'translations', isa => 'HashRef', is => 'rw', default => sub { {} }, traits => ['Hash'],
   handles => {add_translation => 'set'};
 has 'parent', isa => __PACKAGE__, is => 'rw';
@@ -35,10 +34,6 @@ taken from a standardized controlled vocabulary
 
 =over 4
 
-=item name
-
-=item qcode
-
 =item translations
 
 hash mapping IANA language codes to the translation of the name in that language
@@ -67,6 +62,6 @@ Philipp Gortan  C<< <philipp.gortan@apa.at> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, APA-IT. All rights reserved.
+Copyright (c) 2013-2014, APA-IT. All rights reserved.
 
 See L<XML::NewsML_G2> for the license.
