@@ -1,13 +1,12 @@
 package XML::NewsML_G2::Provider;
 
-# $Id: Provider.pm 46519 2013-05-31 15:38:08Z apatecgortan $
+# $Id: Provider.pm 55790 2014-08-26 18:30:30Z apatecgortan $
 
 use Moose;
 use namespace::autoclean;
 
+with 'XML::NewsML_G2::Role::HasQCode';
 
-has 'name', isa => 'Str', is => 'ro', required => 1;
-has 'qcode', isa => 'Str', is => 'ro', required => 1;
 has 'notice', isa => 'Str', is => 'ro';
 
 __PACKAGE__->meta->make_immutable;
@@ -27,10 +26,6 @@ XML::NewsML_G2::Provider - the news provider (news agency)
 
 =over 4
 
-=item name
-
-=item qcode
-
 =item notice
 
 for an optional copyright notice
@@ -43,6 +38,6 @@ Philipp Gortan  C<< <philipp.gortan@apa.at> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, APA-IT. All rights reserved.
+Copyright (c) 2013-2014, APA-IT. All rights reserved.
 
 See L<XML::NewsML_G2> for the license.
