@@ -1,13 +1,11 @@
 package XML::NewsML_G2::Service;
 
-# $Id: Service.pm 46519 2013-05-31 15:38:08Z apatecgortan $
+# $Id: Service.pm 55790 2014-08-26 18:30:30Z apatecgortan $
 
 use Moose;
 use namespace::autoclean;
 
-
-has 'name', isa => 'Str', is => 'ro', required => 1;
-has 'qcode', isa => 'Str', is => 'ro', required => 1;
+with 'XML::NewsML_G2::Role::HasQCode';
 
 __PACKAGE__->meta->make_immutable;
 
@@ -29,6 +27,6 @@ Philipp Gortan  C<< <philipp.gortan@apa.at> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, APA-IT. All rights reserved.
+Copyright (c) 2013-2014, APA-IT. All rights reserved.
 
 See L<XML::NewsML_G2> for the license.
